//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraInfo](index.md)

# HoraInfo

interface [HoraInfo](index.md)

和牌信息

#### Inheritors

| |
|---|
| [Hora](../-hora/index.md) |
| [HoraHandPattern](../-hora-hand-pattern/index.md) |

## Properties

| Name | Summary |
|---|---|
| [agari](agari.md) | [common]<br>abstract val [agari](agari.md): [Tile](../../mahjongutils.models/-tile/index.md)<br>和牌张 |
| [hu](hu.md) | [common]<br>abstract val [hu](hu.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)<br>符数 |
| [roundWind](round-wind.md) | [common]<br>abstract val [roundWind](round-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)?<br>场风 |
| [selfWind](self-wind.md) | [common]<br>abstract val [selfWind](self-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)?<br>自风 |
| [tsumo](tsumo.md) | [common]<br>abstract val [tsumo](tsumo.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>是否自摸 |
